%% Transformer_calculation_normal.m
% 05.01.2022 - Philipp Mueller
%
% In addition to the Matlab script "Transformer_calculation_supra.m"
% this Matlab script shows an exemplary design process of a normal
% conductive railway transformer. 
% The transformer consists of an u-shaped iron core, 
% a normal conductive primary and secondary windings.
% Based on the winding voltage "u_w" all relevant transformer parameters are
% calculated and plotted.
% In this design process, the total material costs were chosen as optimization criteria. 
% 
% The design example was topic of the lecture Superconducting Power Systems
% which was held on December 21st 2021.
% All code sections have headings that refer to the associated lecture
% slides.



%% Initiation
clearvars;

%% Setting the default values and selecting the operating frequency
% During the design process, a comparison between two different operatin
% fequencies (16.667Hz and 50Hz) was made. 
% By choosing one frequency, the according default values
% are loaded.


%freq=16.667;
freq=50;
switch freq
    case 16.667
        P_N=4800e3;         %Nominal power (W)
        U_os=15e3;          %Primary voltage, rms (V)
        U_us=1850;          %Secondary voltage, rms (V)             
        u_k_soll=0.27;      %Required relative short circuit voltage
        f=16.667;           %Operating frequency (Hz)
        B_H=1.7;            %Amplitude of magneteic flux denistiy inside the iron core (T)
        
    case 50
        P_N=5000e3;         %Nominal power (W)
        U_os=25e3;          %Primary voltege, rms (V)
        U_us=1850;          %Secondary votlage, rms (V)
        u_k_soll=0.4;       %Required relative short circuit voltage
        f=50;               %Operating frequency (Hz)
        B_H=1.5;            %Ampitude of magnetic flux denistiy inside the iron core (T)
    
    otherwise
        warning('invalid operating frequecy!')
end

P_max=5175e3;       %Maximum transmitted power (W)
P_b_us=P_max*1.05;  %Rated power of superconductors (W)

u_w_min=10;         %Minimum winding voltage (V)
u_w_max=50;         %Maximum winding voltage (V)

phi_Fe=0.95;        %iron fill factor


a_w_os_us=10e-3;    %Distance between primary and secondary windings (m)
a_l_us=15e-3;       %Distance between secondyry windings (m)
a_i_os_max=10e-3;

h_delta_os=50e-3;   %Distance between prinary windings and ice core yoke (y-direction) (m)

x_max=2500e-3;      %Maximum width of the transformer (m)
y_max=3400e-3;      %Maximum heigth of the transformer (m)
z_max=700e-3;       %Maximum thickness of the transformer (m)
delta_z=50e-3;      %Reserved space for isolation (m)
d_max=z_max-delta_z;%Design thickness for windings (m)

m_max=6500;         %Maximum total weight of the transformer (kg)

mu_0=pi*4e-7;       %Magnetic field constant (N/A^2)
mu_r_Fe=1000;       %Relative permeability, iron

j_Cu=3;             %Design current density of copper (A/mm^2)
j_Al=2;             %Design current density of aluminum (A/mm^2)

dichte_Fe=7850;     %Iron density (kg/m^3)
dichte_Cu=8920;     %Copper density (kg/m^3)
dichte_Al=2700;     %Aluminum density (kg/m^3)

rho_Cu=0.0171;      %Specific resistance of copper ((Ohm*mm^2)/m)
rho_Al=0.0265;      %Specific resistance of aluminum ((Ohm*mm^2)/m)

v_Fe=0.85;          %Iron loss parameter (W/kg)

k_Fe=9;             %Specific iron costs  (/kg)     (vgl. Berger.2011)
k_Cu=15;            %Specific copper costs  (/kg)     (50/kA*m, vgl. Berger.2011--> approx. 15/kg)


%% Choose of conductor material
% In addition to the comparison of freqnencies, a comparison of different
% conductor materials was made. Possible materials for the primary windings
% are for example copper and aluminum.

Leitermaterial='Cu'; 
%Leitermaterial='Al';

switch Leitermaterial
    case 'Cu'
        j_Leiter=j_Cu;             
        rho_Leiter=rho_Cu;
        dichte_Leiter=dichte_Cu;
    case 'Al'
        j_Leiter=j_Al;             
        rho_Leiter=rho_Al;
        dichte_Leiter=dichte_Al;
    otherwise
        warning('Invalid conductor material!');
end

%% First iteration %% 
% The winding voltage u_w is the run variable of this script and of the
% design process. To only consider integer numbers of turns, only winding
% voltages which result in integer numbers of turns are used.

u_w=U_us/u_w_min:-1:U_us/u_w_max;   %Creating a vector with integer numbers of turns
u_w=U_us./u_w;                      %Converting the number of turns into winding voltages


%% Calculation of number of turns (Slide 8 - Design process(2))

w_us=U_us./u_w;                     %number of turns, secondary side
w_os=round(U_os./u_w);              %number of turns, primary side (rounded)
%% Calculation of currents

I_os=P_N/U_os;                      %Primary curent, rms (A)
I_us=P_N/(4*U_us);                  %Secondary current, rms (A)

%% Calculation of iron cross section (Slide 8 - Design process(2))

A_Fe_eff =(u_w)./(sqrt(2)*pi*f*B_H);         %Effektive iron cross section (m^2)
d_Fe=2*sqrt(A_Fe_eff./(phi_Fe*pi));          %Iron diameter (m)

%% Calculation of required stray inductance (Slide 14 - Design process(6))
%The relative short circuit voltage u_k is directly proportional to the
%stray inductance of a transformer. As a required relative short circuit
%voltage is given, the stray inductance can be calculated from it

L_sig=(u_k_soll.*U_os)/(2*pi*f.*I_os);                       %Required stray inductance (H)
L_sig_1_soll=L_sig/2;                                        %Required primary stray inductance (H)
L_sig_2_soll=L_sig_1_soll*((w_us./w_os).^2);                 %Required secondary stray inductance (H)%

%% Design of winding structure, primary side (Slide 9 - Design process (3))
%As the primary windings are not built from superconductors, 
%they are significantly bigger than the secondary windings.
%To minimize the transformers height and to maximize its thickness, 
%the total thickness is set to d_max=650mm.
%This gives a reserve of 50mm for isolation purposes.
%From the set thickness and the number of turns, the height of the primary windings is calculated.
%The conductor cross section is considered to be of a square shape.

A_Leiter_os=I_os/j_Leiter;                              %Conductor cross section, primary side (mm^2)
h_Leiter_os=ceil(sqrt(A_Leiter_os))*1e-3;               %Conductor height, primary side(m)
b_Leiter_os=ceil(sqrt(A_Leiter_os))*1e-3;               %Conductor width, primary side(m)

b_w_os_max=(d_max-d_Fe-(2*a_i_os_max))./2;              %Maximum width of primary winding(m)

%Checking, whether b_w_os_max >= 0
j=find(0>=b_w_os_max);                                  
b_w_os_max(j)=NaN;
clear j;

n_layer_os=floor(b_w_os_max./b_Leiter_os);              %Number of layers, R-direction

%Checking, whether n_layer_os >= 0
j=find(0>=n_layer_os);                                  
n_layer_os(j)=NaN;
clear j;


n_h_os=ceil(w_os./n_layer_os);                          %Number of turns, y-direction

h_w_os=n_h_os.*h_Leiter_os;                             %Height of primary winding (m)
b_w_os=n_layer_os.*b_Leiter_os;                         %Width of primary windning (m)

%% Calculating the stray gap a_i_os (Slide 16 -Design process (8))
a_i_os=-((d_Fe/2)+(b_w_os/3))+sqrt(((d_Fe/2)+(b_w_os/3)).^2-(((b_w_os).^2)/6)-((b_w_os.*d_Fe)./3)+((L_sig_1_soll.*h_w_os)./(mu_0.*(w_os.^2).*pi)));  %Distance between primary winding and iron core (m)

% Checking, wheter a_i_os > 0
j=find(0>=a_i_os);
a_i_os(j)=0;
clear j;



%% Design of winding structure, secondary side (Slide 11 -Design process (4))
%
% The secondary windings should be as far apart as possible.
% In order not to have to vary another parameter,a minimum distance
% between the traction windings of a_l_us=15mm is defined.
% Since the height of the secondary winding is already fixed, 
% and the primary winding is much larger than the secondary winding due 
% to its high number of turns, the design of the secondary winding
% is based on this. 
% The heights of the primary and secondary windings are set equal
% and the width of the secondary winding can be determined from this.

A_Leiter_us=I_us/j_Leiter;                              %Conductor cross section, secondary side (mm^2)
h_Leiter_us=ceil(sqrt(A_Leiter_us))*1e-3;               %Conductor height, secondary side(m)
b_Leiter_us=ceil(sqrt(A_Leiter_us))*1e-3;               %Conductor width, secondary side(m)


h_w_us_max=h_w_os;                                                  %Height of secondary winding (m)
n_h_us_max=floor((h_w_us_max-3*a_l_us)/(4*h_Leiter_us));            %Number of turns, y-direction
n_layer_us=ceil(w_us./n_h_us_max);                                  %Number of layers, R-direction
n_h_us=ceil(w_us./n_layer_us);                                      %Number of layers, y-direction
h_w_us=(n_h_us.*4.*h_Leiter_us);

b_w_us=n_layer_us.*b_Leiter_us;                                     %Width of secondary windning (m)


%% Calculating the stray gap a_i_us (Slide 16 - Design process (8))
a_i_us=-((d_Fe/2)+(b_w_us/3))+sqrt(((d_Fe/2)+(b_w_us/3)).^2-(((b_w_us).^2)/6)-((b_w_us.*d_Fe)./3)+((L_sig_2_soll.*h_w_us)./(mu_0.*(w_us.^2)*pi))); %Distance between secondary winding and iron core (m)


%Checking, whether a_i_us > 0
j=find(0>=a_i_us);
a_i_us(j)=0;
clear j;

%% Calculation of dimensions and weight (Slide 17ff. - Design process (9,10))
d_t_os=d_Fe+2*a_i_os+2*b_w_os;                                              %Transformer thickness, primary side (m)
d_t_us=d_Fe+2*a_i_us+2*b_w_us;                                              %Transformer thickness, secondary side (m)
b_f=((d_t_os+d_t_us-2*d_Fe)/2)+a_w_os_us;                                   %Width of iron core window (m)
h_f=h_w_os+2*h_delta_os;                                                    %Height of iron core window (m)
b_k=b_f+2*d_Fe;                                                             %Width of iron core (m)
h_k=h_f+2*d_Fe;                                                             %Heigth of iron core (m)         
b_t=((d_t_os+d_t_us)./2)+b_f+d_Fe;                                          %Transformer width, x-direction (m)

l_Fe_eff=2*(h_k-d_Fe)+2*(b_k-d_Fe);                                         %Effective iron length (m)
l_Leiter_os=w_os*pi.*(d_Fe+(n_layer_os.*b_Leiter_os)+2*a_i_os);             %Conductor length, primary side (m)
l_Leiter_us=4*(w_us*pi.*(d_Fe+(n_layer_us.*b_Leiter_us)+2*a_i_us));         %Conductor length, secondary side (m)

V_Fe=A_Fe_eff.*(h_f+b_k)*2;                                                 %Iron volume (m^3)
V_Leiter_os=(A_Leiter_os/(1000^2)).*l_Leiter_os;                            %Conductor volume, primary side(m^3)
V_Leiter_us=(A_Leiter_us/(1000^2)).*l_Leiter_us;                            %Conductor volume, secdondary side(m^3)

m_Fe=V_Fe.*dichte_Fe;                                                       %Iron mass (kg)
m_Leiter_os=V_Leiter_os.*dichte_Leiter;                                     %Conductor mass, primary side (kg)
m_Leiter_us=V_Leiter_us.*dichte_Leiter;                                     %Conductor mass, secondary side (kg)
m_gesamt=m_Fe+m_Leiter_os+m_Leiter_us;                                      %Total mass (kg)

%% Calculation of conductor Resistance (Slide 19 - Design process (11))

R_os=rho_Leiter*(l_Leiter_os./A_Leiter_os);         %Resistance of primary winding (Ohm)
R_us=rho_Leiter*(l_Leiter_us./A_Leiter_us);         %Resistance of secondary winding (Ohm)

%% Calculation of losses (Slide 19 - Design process (11))

P_Wicklung_os=(I_os^2)*R_os;                %Copper losses, primary side (W)
P_Wicklung_us=4*((I_us^2)*R_us);            %Copper losses, secondary side (W)
P_Fe=v_Fe*m_Fe;                             %Iron losses (W)
P_v_ges=P_Wicklung_os+P_Wicklung_us+P_Fe;   %Total losses (W) 

%% Efficiency (Slide 19 - Design process (11))
eta=1-(P_v_ges./P_N);

%% Calculation of costs (Slide 19 - Design process (11))
K_Fe=k_Fe*m_Fe;                             %Iron costs ()
K_Cu_os=k_Cu*m_Leiter_os;                   %Copper costs, primary side ()
K_Cu_us=k_Cu*m_Leiter_us;                   %Copper costs, secondary side ()
K_ges=K_Fe+K_Cu_os+K_Cu_us;                 %Total costs ()

%% Plotting results (Slide 25ff.)

% Defining colors
orange=[0.8500, 0.3250, 0.0980];
blue=[0, 0.4470, 0.7410];
yellow=[0.9290, 0.6940, 0.1250];
purple=[0.4940, 0.1840, 0.5560];
green=[0.4660, 0.6740, 0.1880];


% Plot of dimensions
figure
hold on
plot(u_w,1000*b_t,'color',blue,'LineWidth',2)
plot(u_w,1000*h_k,'color',orange,'LineWidth',2)
plot(u_w,1000*d_t_os,'color',purple,'LineWidth',2)
title({'1. Iteration','Transformer dimensions in dependency of the winding voltage u_w'})
xlabel('Winding voltage u_w / V')
ylabel('Transformer dimensions / mm')
yline(1000*y_max,'--','h_{y,max}','LabelHorizontalAlignment','right','color',orange,'LineWidth',2)
yline(1000*z_max,'--','h_{z,max}','LabelHorizontalAlignment','right','color',purple,'LineWidth',2)
yline(1000*x_max,'--','h_{x,max}','LabelHorizontalAlignment','right','color',blue,'LineWidth',2)
legend('h_x','h_y','h_z','Location','northeastoutside')
grid on

% Plot of weight
figure
hold on
plot(u_w,m_Fe,'color',blue,'LineWidth',2)
plot(u_w,m_Leiter_os+m_Leiter_us,'color',orange,'LineWidth',2)
plot(u_w,m_Fe+m_Leiter_os+m_Leiter_us,'color',purple,'LineWidth',2)
title({'1. Iteration','Transformer weight in dependency of the winding voltage u_w'})
xlabel('Winding voltage u_w / V')
ylabel('Mass / kg')
yline(m_max,'--k','m_{max}','LabelHorizontalAlignment','right','LineWidth',2)
formatSpec1='m_{%s}';
formatSpec2='m_{%s,us}';
formatSpec3='m_{Fe}+m_{%s}';
legend('m_{Fe}',sprintf(formatSpec1,Leitermaterial),sprintf(formatSpec3,Leitermaterial),'Location','northeastoutside')
grid on

% Plot of losses
figure
hold on
plot(u_w,P_Fe/1000,'color',blue,'LineWidth',2)
plot(u_w,(P_Wicklung_os)/1000,'color',orange,'LineWidth',2)
plot(u_w,(P_Wicklung_us)/1000,'color',green,'LineWidth',2)
plot(u_w,(P_Fe+P_Wicklung_os+P_Wicklung_us)/1000,'color',purple,'LineWidth',2)
title({'1. Iteration','Transformer losses in dependency of the winding voltage u_w'})
xlabel('Winding voltage u_w / V')
ylabel('Losses / kW')
legend('P_{Fe}','P_{Cu,os}','P_{Cu,us}','P_{Fe}+P_{Cu,os}+P_{Cu,us}','Location','northeastoutside')
grid on
hold off


% Plot of costs
figure
hold on
pl=plot(u_w,K_Fe,'-','color',blue,'LineWidth',2);
plot(u_w,K_Cu_os+K_Cu_us,'-','color',orange,'LineWidth',2)
plot(u_w,K_ges,'-','color',purple,'LineWidth',2)
legend('K_{Fe}','K_{Cu}','K_{tot}','Location','northeastoutside')
title({'1. Iteration','Transformer costs in dependency of the winding voltage u_w'})
ax = ancestor(pl, 'axes');
ax.YAxis.Exponent = 0;
ytickformat(ax, '%d');
xlabel('Winding voltage u_w / V')
ylabel('Costs / ')
grid on
hold off

%% Eliminating invaldid winding voltages (Slide 29 - Verification)
% As the range of winding voltages was set empirically, its not
% guaranteed, that all winding voltages leed to an valid transformer
% design. The fulfillment of all boundary conditions needs to be checked
% and the range of winding voltages is set to only valid values

q=find((0<a_i_os)&(0<a_i_us)&(h_k<y_max)&(d_t_os<z_max)&(d_t_us<z_max)&(b_t<x_max));  %Checking, wheter all boundyrfy conditions are fulfilled
if isempty(q)==0
    u_w_min=u_w(q(1));                                              %Setting the minimum winding voltage
    u_w_max=u_w(q(end));                                            %Setting the maximum winding voltage
else
    u_w_min=NaN;
    u_w_max=NaN;
end

clear q;


%% Second iteration %%

% The winding voltage u_w is the run variable of this script and of the
% design process. To only consider integer numbers of turns, only winding
% voltages which result in integer numbers of turns are used.

u_w=U_us/u_w_min:-1:U_us/u_w_max;   %Creating a vector with integer numbers of turns
u_w=U_us./u_w;                      %Converting the number of turns into winding voltages


%% Calculation of number of turns (Slide 8 - Design process(2))

w_us=U_us./u_w;                     %number of turns, secondary side
w_os=round(U_os./u_w);              %number of turns, primary side (rounded)
%% Calculation of currents

I_os=P_N/U_os;                      %Primary curent, rms (A)
I_us=P_N/(4*U_us);                  %Secondary current, rms (A)

%% Calculation of iron cross section (Slide 8 - Design process(2))

A_Fe_eff =(u_w)./(sqrt(2)*pi*f*B_H);         %Effektive iron cross section (m^2)
d_Fe=2*sqrt(A_Fe_eff./(phi_Fe*pi));          %Iron diameter (m)

%% Calculation of required stray inductance (Slide 14 - Design process(6))
%The relative short circuit voltage u_k is directly proportional to the
%stray inductance of a transformer. As a required relative short circuit
%voltage is given, the stray inductance can be calculated from it

L_sig=(u_k_soll.*U_os)/(2*pi*f.*I_os);                       %Required stray inductance (H)
L_sig_1_soll=L_sig/2;                                        %Required primary stray inductance (H)
L_sig_2_soll=L_sig_1_soll*((w_us./w_os).^2);                 %Required secondary stray inductance (H)%

%% Design of winding structure, primary side (Slide 9 - Design process (3))
%As the primary windings are not built from superconductors, 
%they are significantly bigger than the secondary windings.
%To minimize the transformers height and to maximize its thickness, 
%the total thickness is set to d_max=650mm.
%This gives a reserve of 50mm for isolation purposes.
%From the set thickness and the number of turns, the height of the primary windings is calculated.
%The conductor cross section is considered to be of a square shape.

A_Leiter_os=I_os/j_Leiter;                              %Conductor cross section, primary side (mm^2)
h_Leiter_os=ceil(sqrt(A_Leiter_os))*1e-3;               %Conductor height, primary side(m)
b_Leiter_os=ceil(sqrt(A_Leiter_os))*1e-3;               %Conductor width, primary side(m)

b_w_os_max=(d_max-d_Fe-(2*a_i_os_max))./2;              %Maximum width of primary winding(m)

%Checking, whether b_w_os_max >= 0
j=find(0>=b_w_os_max);                                  
b_w_os_max(j)=NaN;
clear j;

n_layer_os=floor(b_w_os_max./b_Leiter_os);              %Number of layers, R-direction

%Checking, whether n_layer_os >= 0
j=find(0>=n_layer_os);                                  
n_layer_os(j)=NaN;
clear j;


n_h_os=ceil(w_os./n_layer_os);                          %Number of turns, y-direction

h_w_os=n_h_os.*h_Leiter_os;                             %Height of primary winding (m)
b_w_os=n_layer_os.*b_Leiter_os;                         %Width of primary windning (m)

%% Calculating the stray gap a_i_os (Slide 16 -Design process (8))
a_i_os=-((d_Fe/2)+(b_w_os/3))+sqrt(((d_Fe/2)+(b_w_os/3)).^2-(((b_w_os).^2)/6)-((b_w_os.*d_Fe)./3)+((L_sig_1_soll.*h_w_os)./(mu_0.*(w_os.^2).*pi)));  %Distance between primary winding and iron core (m)

% Checking, wheter a_i_os > 0
j=find(0>=a_i_os);
a_i_os(j)=0;
clear j;



%% Design of winding structure, secondary side (Slide 11 -Design process (4))
%
% The secondary windings should be as far apart as possible.
% In order not to have to vary another parameter,a minimum distance
% between the traction windings of a_l_us=15mm is defined.
% Since the height of the secondary winding is already fixed, 
% and the primary winding is much larger than the secondary winding due 
% to its high number of turns, the design of the secondary winding
% is based on this. 
% The heights of the primary and secondary windings are set equal
% and the width of the secondary winding can be determined from this.

A_Leiter_us=I_us/j_Leiter;                              %Conductor cross section, secondary side (mm^2)
h_Leiter_us=ceil(sqrt(A_Leiter_us))*1e-3;               %Conductor height, secondary side(m)
b_Leiter_us=ceil(sqrt(A_Leiter_us))*1e-3;               %Conductor width, secondary side(m)


h_w_us_max=h_w_os;                                                  %Height of secondary winding (m)
n_h_us_max=floor((h_w_us_max-3*a_l_us)/(4*h_Leiter_us));            %Number of turns, y-direction
n_layer_us=ceil(w_us./n_h_us_max);                                  %Number of layers, R-direction
n_h_us=ceil(w_us./n_layer_us);                                      %Number of layers, y-direction
h_w_us=(n_h_us.*4.*h_Leiter_us);

b_w_us=n_layer_us.*b_Leiter_us;                                     %Width of secondary windning (m)


%% Calculating the stray gap a_i_us (Slide 16 - Design process (8))
a_i_us=-((d_Fe/2)+(b_w_us/3))+sqrt(((d_Fe/2)+(b_w_us/3)).^2-(((b_w_us).^2)/6)-((b_w_us.*d_Fe)./3)+((L_sig_2_soll.*h_w_us)./(mu_0.*(w_us.^2)*pi))); %Distance between secondary winding and iron core (m)


%Checking, whether a_i_us > 0
j=find(0>=a_i_us);
a_i_us(j)=0;
clear j;

%% Calculation of dimensions and weight (Slide 17ff. - Design process (9,10))
d_t_os=d_Fe+2*a_i_os+2*b_w_os;                                              %Transformer thickness, primary side (m)
d_t_us=d_Fe+2*a_i_us+2*b_w_us;                                              %Transformer thickness, secondary side (m)
b_f=((d_t_os+d_t_us-2*d_Fe)/2)+a_w_os_us;                                   %Width of iron core window (m)
h_f=h_w_os+2*h_delta_os;                                                    %Height of iron core window (m)
b_k=b_f+2*d_Fe;                                                             %Width of iron core (m)
h_k=h_f+2*d_Fe;                                                             %Heigth of iron core (m)         
b_t=((d_t_os+d_t_us)./2)+b_f+d_Fe;                                          %Transformer width, x-direction (m)

l_Fe_eff=2*(h_k-d_Fe)+2*(b_k-d_Fe);                                         %Effective iron length (m)
l_Leiter_os=w_os*pi.*(d_Fe+(n_layer_os.*b_Leiter_os)+2*a_i_os);             %Conductor length, primary side (m)
l_Leiter_us=4*(w_us*pi.*(d_Fe+(n_layer_us.*b_Leiter_us)+2*a_i_us));         %Conductor length, secondary side (m)

V_Fe=A_Fe_eff.*(h_f+b_k)*2;                                                 %Iron volume (m^3)
V_Leiter_os=(A_Leiter_os/(1000^2)).*l_Leiter_os;                            %Conductor volume, primary side(m^3)
V_Leiter_us=(A_Leiter_us/(1000^2)).*l_Leiter_us;                            %Conductor volume, secdondary side(m^3)

m_Fe=V_Fe.*dichte_Fe;                                                       %Iron mass (kg)
m_Leiter_os=V_Leiter_os.*dichte_Leiter;                                     %Conductor mass, primary side (kg)
m_Leiter_us=V_Leiter_us.*dichte_Leiter;                                     %Conductor mass, secondary side (kg)
m_gesamt=m_Fe+m_Leiter_os+m_Leiter_us;                                      %Total mass (kg)


%% Calculating magnetic parameters

%Calculations of Inductances and magnetic flux are based on the lecture
%"Elektroenergiesysteme" from Prof Dr.-Ing Thomas Leibfried (KIT)
%Stray inductances are calculated by integrating the magnetic stray field
%In addition, the coupling factor and the scattering factor are determined,
%which provide information about the magnetic coupling of the transformer
%
%Assumption: R_m_1=R_m_2

%Calculating relcutances
R_m_1=l_Fe_eff./(2*mu_0*mu_r_Fe.*A_Fe_eff); %Reluctance - left side (Ohm)
R_m_2=l_Fe_eff./(2*mu_0*mu_r_Fe.*A_Fe_eff); %Reluctance - right side (Ohm)
G_m_h=1./(R_m_1+R_m_2);                     %Main Admittance (1/Ohm)

%Calculating main and mutual inductances
M=w_os.*w_us.*G_m_h;                        %Mutual inductance (H)
L_1_h=G_m_h.*(w_os.^2);                     %Main inductance, primary side (H)
L_2_h=G_m_h.*(w_us.^2);                     %Main inductance, secondary side (H)
L_h=M.*(w_os./w_us);                        %Main indutance (H)

%Calculating stray inductances
L_sig_1_ist=2*pi.*((mu_0.*w_os.^2)./h_w_os).*(((a_i_os.^2)/2)+a_i_os.*((d_Fe/2)+b_w_os/3)+((b_w_os.^2)/12)+((b_w_os.*d_Fe)/6)); %Stray inductance, primary side (H)
L_sig_2_ist=2*pi.*((mu_0.*w_us.^2)./h_w_us).*(((a_i_us.^2)/2)+a_i_us.*((d_Fe/2)+b_w_us/3)+((b_w_us.^2)/12)+((b_w_us.*d_Fe)/6)); %Stray inductance, secondary side (H)
L_sig_ist=L_sig_1_ist+((w_os./w_us).^2).*L_sig_2_ist; %Total stry inductance (H)


L_1=L_1_h+L_sig_1_ist;                      %Primary inductance (H)
L_2=L_2_h+L_sig_2_ist;                      %Secondary inductance (H)

%Calculating magnetic flux
Phi_1=(L_1*I_os)./w_os;                     %Primary flux (Wb)
Phi_2=(L_2*4*I_us)./w_us;                   %Secondary flux (Wb)

Phi_12=(M*I_os)./w_us;                      %Main flux, priumary side (Wb)
Phi_21=(M*4*I_us)./w_os;                    %Main flux, secondary side (Wb)

Phi_sigma_1=Phi_1-Phi_12;                   %Stray flux, primary side (Wb)
Phi_sigma_2=Phi_12-Phi_2;                   %Stray flux, secondary side (Wb)



%Calculating coupling- and scattering factor
k=M./sqrt(L_1.*L_2);                        %coupling factor 
sigma=1-(k.^2);                             %scattering factor


u_k=2*pi*f.*L_sig_ist.*(I_os./U_os);        %relative short circuit voltage

%% Calculation of conductor Resistance (Slide 19 - Design process (11))

R_os=rho_Leiter*(l_Leiter_os./A_Leiter_os);         %Resistance of primary winding (Ohm)
R_us=rho_Leiter*(l_Leiter_us./A_Leiter_us);         %Resistance of secondary winding (Ohm)

%% Calculation of losses (Slide 19 - Design process (11))

P_Wicklung_os=(I_os^2)*R_os;                %Copper losses, primary side (W)
P_Wicklung_us=4*((I_us^2)*R_us);            %Copper losses, secondary side (W)
P_Fe=v_Fe*m_Fe;                             %Iron losses (W)
P_v_ges=P_Wicklung_os+P_Wicklung_us+P_Fe;   %Total losses (W) 

%% Efficiency (Slide 19 - Design process (11))
eta=1-(P_v_ges./P_N);

%% Calculation of costs (Slide 19 - Design process (11))
K_Fe=k_Fe*m_Fe;                             %Iron costs ()
K_Cu_os=k_Cu*m_Leiter_os;                   %Copper costs, primary side ()
K_Cu_us=k_Cu*m_Leiter_us;                   %Copper costs, secondary side ()
K_ges=K_Fe+K_Cu_os+K_Cu_us;                 %Total costs ()

%% Plotting results (Slide 25ff.))

% Defining colors
orange=[0.8500, 0.3250, 0.0980];
blue=[0, 0.4470, 0.7410];
yellow=[0.9290, 0.6940, 0.1250];
purple=[0.4940, 0.1840, 0.5560];
green=[0.4660, 0.6740, 0.1880];

% Plot of dimensions
figure
hold on
plot(u_w,1000*b_t,'color',blue,'LineWidth',2)
plot(u_w,1000*h_k,'color',orange,'LineWidth',2)
plot(u_w,1000*d_t_os,'color',purple,'LineWidth',2)
title({'2. Iteration','Transformer dimensions in dependency of the winding voltage u_w'})
xlabel('Winding voltage u_w / V')
ylabel('Transformer dimensions / mm')
yline(1000*y_max,'--','h_{y,max}','LabelHorizontalAlignment','right','color',orange,'LineWidth',2)
yline(1000*z_max,'--','h_{z,max}','LabelHorizontalAlignment','right','color',purple,'LineWidth',2)
yline(1000*x_max,'--','h_{x,max}','LabelHorizontalAlignment','right','color',blue,'LineWidth',2)
legend('h_x','h_y','h_z','Location','northeastoutside')
grid on

% Plot of weights
figure
hold on
plot(u_w,m_Fe,'color',blue,'LineWidth',2)
plot(u_w,m_Leiter_os+m_Leiter_us,'color',orange,'LineWidth',2)
plot(u_w,m_Fe+m_Leiter_os+m_Leiter_us,'color',purple,'LineWidth',2)
title({'2. Iteration','Transformer weight in dependency of the winding voltage u_w'})
xlabel('Winding voltage u_w / V')
ylabel('Mass / kg')
yline(m_max,'--k','m_{max}','LabelHorizontalAlignment','right','LineWidth',2)
formatSpec1='m_{%s}';
formatSpec2='m_{%s,us}';
formatSpec3='m_{Fe}+m_{%s}';
legend('m_{Fe}',sprintf(formatSpec1,Leitermaterial),sprintf(formatSpec3,Leitermaterial),'Location','northeastoutside')
grid on

% Plot of losses
figure
hold on
plot(u_w,P_Fe/1000,'color',blue,'LineWidth',2)
plot(u_w,(P_Wicklung_os)/1000,'color',orange,'LineWidth',2)
plot(u_w,(P_Wicklung_us)/1000,'color',green,'LineWidth',2)
plot(u_w,(P_Fe+P_Wicklung_os+P_Wicklung_us)/1000,'color',purple,'LineWidth',2)
title({'2. Iteration','Transformer losses in dependency of the winding voltage u_w'})
xlabel('Winding voltage u_w / V')
ylabel('Losses / kW')
legend('P_{Fe}','P_{Cu,os}','P_{Cu,us}','P_{Fe}+P_{Cu,os}+P_{Cu,us}','Location','northeastoutside')
grid on
hold off

% Plot of costs
figure
hold on
pl=plot(u_w,K_Fe,'-','color',blue,'LineWidth',2);
plot(u_w,K_Cu_os+K_Cu_us,'-','color',orange,'LineWidth',2)
plot(u_w,K_ges,'-','color',purple,'LineWidth',2)
legend('K_{Fe}','K_{Cu}','K_{tot}','Location','northeastoutside')
title({'2. Iteration','Transformer costs in dependency of the winding voltage u_w'})
ax = ancestor(pl, 'axes');
ax.YAxis.Exponent = 0;
ytickformat(ax, '%d');
xlabel('Winding voltage u_w / V')
ylabel('Costs / ')
grid on
hold off